summaryrefslogtreecommitdiff
path: root/plugins
diff options
context:
space:
mode:
authoralec <alec@208e9e7b-5314-0410-a742-e7e81cd9613c>2010-09-30 06:50:48 +0000
committeralec <alec@208e9e7b-5314-0410-a742-e7e81cd9613c>2010-09-30 06:50:48 +0000
commit03e6e60988ea2b51aaa972e39d143ab705fa5386 (patch)
treeff676d33276f9936e7b3c275f772081301c090d8 /plugins
parent3b151fc1adad6efc065b54073b7c13e652d2823c (diff)
- Extend virtuser_query with email2user and user2host mapping (#1486750)
git-svn-id: https://svn.roundcube.net/trunk@4018 208e9e7b-5314-0410-a742-e7e81cd9613c
Diffstat (limited to 'plugins')
-rw-r--r--plugins/virtuser_query/virtuser_query.php73
1 files changed, 60 insertions, 13 deletions
diff --git a/plugins/virtuser_query/virtuser_query.php b/plugins/virtuser_query/virtuser_query.php
index 2ec24d50e..8f154c235 100644
--- a/plugins/virtuser_query/virtuser_query.php
+++ b/plugins/virtuser_query/virtuser_query.php
@@ -4,31 +4,45 @@
* DB based User-to-Email and Email-to-User lookup
*
* Add it to the plugins list in config/main.inc.php and set
- * SQL query to resolve user names and e-mail addresses from the database
+ * SQL queries to resolve usernames, e-mail addresses and hostnames from the database
* %u will be replaced with the current username for login.
* The query should select the user's e-mail address as first column
* and optional identity data columns in specified order:
* name, organization, reply-to, bcc, signature, html_signature
*
- * $rcmail_config['virtuser_query'] = '';
+ * $rcmail_config['virtuser_query'] = array('email' => '', 'user' => '', 'host' => '');
*
- * @version 1.0
+ * @version 1.1
* @author Aleksander Machniak
+ * @author Steffen Vogel
*/
class virtuser_query extends rcube_plugin
{
- private $query;
+ private $config;
private $app;
function init()
{
$this->app = rcmail::get_instance();
- $this->query = $this->app->config->get('virtuser_query');
+ $this->config = $this->app->config->get('virtuser_query');
- if ($this->query) {
- $this->add_hook('user2email', array($this, 'user2email'));
-// $this->add_hook('email2user', array($this, 'email2user'));
- }
+ if (!empty($this->config)) {
+ if (is_string($this->config)) {
+ $this->config = array('email' => $this->config);
+ }
+
+ if ($this->config['email']) {
+ $this->add_hook('user2email', array($this, 'user2email'));
+ }
+ if ($this->config['user']) {
+ $this->add_hook('email2user', array($this, 'email2user'));
+ }
+ if ($this->config['host']) {
+ $this->add_hook('authenticate', array($this, 'user2host'));
+ }
+ }
}
/**
@@ -38,7 +52,7 @@ class virtuser_query extends rcube_plugin
{
$dbh = $this->app->get_dbh();
- $sql_result = $dbh->query(preg_replace('/%u/', $dbh->escapeSimple($p['user']), $this->query));
+ $sql_result = $dbh->query(preg_replace('/%u/', $dbh->escapeSimple($p['user']), $this->config['email']));
while ($sql_arr = $dbh->fetch_array($sql_result)) {
if (strpos($sql_arr[0], '@')) {
@@ -61,10 +75,43 @@ class virtuser_query extends rcube_plugin
break;
}
}
-
+
$p['email'] = $result;
return $p;
}
+ /**
+ * EMail > User
+ */
+ function email2user($p)
+ {
+ $dbh = $this->app->get_dbh();
+
+ $sql_result = $dbh->query(preg_replace('/%m/', $dbh->escapeSimple($p['email']), $this->config['user']));
+
+ if ($sql_arr = $dbh->fetch_array($sql_result)) {
+ $p['user'] = $sql_arr[0];
+ }
+
+ return $p;
+ }
+
+ /**
+ * User > Host
+ */
+ function user2host($p)
+ {
+ $dbh = $this->app->get_dbh();
+
+ $sql_result = $dbh->query(preg_replace('/%u/', $dbh->escapeSimple($p['user']), $this->config['host']));
+
+ if ($sql_arr = $dbh->fetch_array($sql_result)) {
+ $p['host'] = $sql_arr[0];
+ }
+
+ return $p;
+ }
+
}
+
@@ -4,31 +4,45 @@
* %u will be replaced with the current username for login.
- * The query should select the user's e-mail address as first column
- * and optional identity data columns in specified order:
+ * %m will be replaced with the current e-mail address for login.
+ *
+ * Queries should select the user's e-mail address, username or the imap hostname as first column
+ * The email query could optionally select identity data columns in specified order:
* name, organization, reply-to, bcc, signature, html_signature
*